# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py.py
@Date    : 2024/2/4 10:03:54
@Author  : zhchen
@Desc    : 
"""
import re

import requests

from lqbox.base import BaseBox


class AliBox(BaseBox):

    def __init__(self, cookies):
        super().__init__(cookies)
        self.headers = {
            'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/123.0.0.0 Safari/537.36',
        }
        self.get_csrf_token()

    def request(self, method, url, **kwargs):
        if kwargs.get('headers') is None:
            kwargs['headers'] = self.headers
        return super().request(method, url, **kwargs)

    def get_csrf_token(self):
        """获取csrf_token"""
        params = {
            'isShare': 'true',
            'hideTopbar': 'true',
            'readOnly': 'true',
            'hiddenQuickAnalysis': 'true',
            'hiddenLogReduce': 'true',
            'hiddenLogChart': 'true',
            'hiddenBack': 'true',
            'hiddenChangeProject': 'true',
            'hiddenOverview': 'true',
            'ignoreTabLocalStorage': 'true',
            'hiddenShare': 'true',
            'hiddenEtl': 'true',
            'hiddenProject': 'true',
            'hiddenReport': 'true',
            'hiddenTitleSetting': 'true',
        }

        response = self.request(
            url=f"{self.base_url}/lognext/project/octet/logsearch/elastic-oc",
            method="GET", params=params)
        csrf_token = re.findall(r'SEC_TOKEN: \"(.*)\"', response.text)[0]
        self.headers['X-Csrf-Token'] = str(csrf_token)


class AliLogBox(AliBox):
    base_url = "aHR0cHM6Ly9zbHM0c2VydmljZS5jb25zb2xlLmFsaXl1bi5jb20="

    @classmethod
    def login_from_mc(cls, url):
        session = requests.Session()
        response = session.get(url)
        cookies = dict(session.cookies)
        # print(cookies)
        return cls(cookies)

    def __ali_log_request(self, path, data):
        return self.request(url=f"{self.base_url}{path}", method="POST", data=data)

    def get_logs(self, data):
        """获取日志"""
        # data = {
        #     'ProjectName': '123',
        #     'LogStoreName': '123',
        #     'from': '1706976000',
        #     'query': 'exp | with_pack_meta',
        #     'to': '1707014768',
        #     'Page': '1',
        #     'Size': '20',
        #     'Reverse': 'true',
        #     'pSql': 'false',
        #     'schemaFree': 'false',
        #     'needHighlight': 'true',
        # }
        return self.__ali_log_request(path="/console/logs/getLogs.json", data=data)



# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py
@Date    : 2023/8/25 10:51:23
@Author  : zhchen
@Desc    : 
"""
from lqbox.base import BaseBox


class ElihuBox(BaseBox):
    base_url = 'aHR0cHM6Ly9lbGlodS1taW5lci5sZXFlZS5jb20='

    def __elihu_request(self, path, json_data):
        return self.request(url=f"{self.base_url}{path}", method="POST", json=json_data)

    def _get_target_machine_list(self):
        """获取所有机器"""
        return self.__elihu_request(path="/api/ScheduleController/getTargetMachineList", json_data={})

    def queue_search(self, json_data):
        """查询队列"""
        # json_data = {
        #     'page': 1,
        #     'page_size': 10,
        #     'status': ['INIT', 'ENQUEUED', 'RUNNING', 'DONE', 'ERROR', 'DEAD', 'CANCELLED'],
        #     'task_id': '1234',
        #     'enqueue_time': [
        #         '2023/04/24 05:00:00',
        #         '2023/04/26 00:00:00',
        #     ],
        #     'title': 'API',
        #     'schedule_id': '1',
        #     'target_machine': 'machine002',
        # }
        return self.__elihu_request(path='/api/QueueController/listTasksInQueue', json_data=json_data)

    def queue_fork(self, json_data):
        """fork一个task"""
        # json_data = {
        #     'task_id': 1234,
        #     'enqueue_now': 'NO',
        # }
        return self.__elihu_request(path='/api/QueueController/forkTask', json_data=json_data)

    def queue_cancel(self, json_data):
        """取消一个任务到队列, task状态必须是INIT"""
        # json_data = {
        #     'task_id': 1234,
        # }
        return self.__elihu_request(path='/api/QueueController/cancelTask', json_data=json_data)

    def queue_enqueue(self, json_data):
        """进入队列"""
        # json_data = {
        #     'task_id': 1234,
        # }
        return self.__elihu_request(path='/api/QueueController/enqueueTask', json_data=json_data)

    def queue_mark_dead(self, json_data):
        """kill一个task, 并且会标记为ERROR"""
        # json_data = {
        #     'task_id': 1234,
        # }
        return self.__elihu_request(path='/api/QueueController/registerTimeoutForTask', json_data=json_data)

    def schedules_load(self, json_data):
        """查询调度时间"""
        # json_data = {
        #     'page': 1,
        #     'page_size': 10,
        #     'status': ['ON', 'OFF', 'NEVER'],
        #     'title': '123',
        # }
        return self.__elihu_request(path='/api/ScheduleController/fetchScheduleList', json_data=json_data)

    def schedules_run_once(self, json_data):
        """立即执行一次"""
        # json_data = {
        #     'schedule_id': 123,
        #     'enqueue_now': 'YES',
        # }
        return self.__elihu_request(path='/api/QueueController/createRunOnceTaskFromSchedule', json_data=json_data)

    def schedules_machine(self):
        """查询所有机器"""
        return self.__elihu_request(path='/api/ScheduleController/getTargetMachineList', json_data={})



# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py
@Date    : 2023/8/25 10:58:45
@Author  : zhchen
@Desc    : 
"""
import base64
import hashlib

import requests


class BaseBox:
    base_url = None

    def __init__(self, cookies):
        self.cookies = cookies
        self.check()

    def check(self):
        if not self.base_url:
            raise ValueError("base_url is None")

        self.base_url = self.base64(self.base_url)

    def request(self, method, url, **kwargs):
        if kwargs.get('headers') is None:
            kwargs['headers'] = {
                'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36',
            }
        if kwargs.get("cookies") is None:
            kwargs['cookies'] = self.cookies
        return requests.request(method, url, **kwargs)

    @staticmethod
    def md5(string: str) -> str:
        """生成MD5"""
        hl = hashlib.md5()
        hl.update(string.encode(encoding='utf-8'))
        return hl.hexdigest()

    @staticmethod
    def base64(string: str) -> str:
        """base64解码"""
        decoded_bytes = base64.b64decode(string)
        return decoded_bytes.decode('utf-8')



# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py
@Date    : 2024/2/2 17:19:22
@Author  : zhchen
@Desc    : 
"""
from lqbox.base import BaseBox


class McBox(BaseBox):
    base_url = 'aHR0cHM6Ly9tYy5sZXFlZS5jb20='

    def __init__(self, cookies):
        self.token = None
        super().__init__(cookies)

    def check(self):
        super().check()
        self.token = self.cookies.get("token")
        if not self.token:
            raise ValueError("token is None")

    def __mc_request(self, path, json_data):
        return self.request(url=f"{self.base_url}{path}", method="POST", json=json_data)

    def get_current_user_info(self):
        """获取用户信息"""
        return self.__mc_request(path='/api/UserController/getCurrentUserInfo', json_data={"token": self.token})

    def get_account_project(self, account: str):
        """获取日志project"""
        return self.__mc_request(
            path='/spore/api/sls/getAccountProject',
            json_data={'account': account, 'token': self.token}
        )

    def get_project_log_store(self, json_data):
        """获取对应的日志store"""
        # json_data = {
        #     'account': '123',
        #     'project': '123',
        # }
        return self.__mc_request(
            path='/spore/api/sls/getProjectLogStore',
            json_data={**json_data, "token": self.token}
        )

    def get_sls_iframe_url(self, json_data):
        """获取阿里云令牌url"""
        # json_data = {
        #     'account': '123',
        #     'project': '123',
        #     'logstore': '123',
        # }
        return self.__mc_request(
            path='/spore/api/sls/getSLSIframeUrl',
            json_data={**json_data, "token": self.token}
        )



# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py.py
@Date    : 2023/8/28 11:00:58
@Author  : zhchen
@Desc    : 
"""
import datetime
from typing import List, Iterable

from requests import Response

from lqbox.base import BaseBox


class OpenElihuBox(BaseBox):
    base_url = "aHR0cHM6Ly9lbGlodS1taW5lci5sZXFlZS5jb20vb3BlbmFwaQ=="
    name1 = 'ZWxpaHUtb3Blbi1hcGktdHAtY29kZQ=='
    name2 = 'ZWxpaHUtb3Blbi1hcGktbm9pc2U='
    name3 = 'ZWxpaHUtb3Blbi1hcGktY2hlY2tzdW0='

    def __init__(self, tp_code, tp_secret):
        super().__init__(cookies={})
        self.tp_code = tp_code
        self.tp_secret = tp_secret

    def request_open_api(self, api_path, body) -> Response:
        now = datetime.datetime.now().strftime('%Y%m%d%H%M%S%f')
        body[self.base64(self.name1)] = self.tp_code
        body[self.base64(self.name2)] = now
        body[self.base64(self.name3)] = self.md5(f'{self.tp_code}{now}{self.tp_secret}')
        r = self.request(method='POST', url=f'{self.base_url}/{api_path}', json=body)
        return r

    def call_check_task_detail(self, task_id: int) -> Response:
        """获取某个任务的状态"""
        return self.request_open_api(
            api_path="QueueOpenApiController/checkTaskDetail",
            body={"task_id": task_id}
        )

    def call_get_shovel_request_related_accounts(
            self,
            shovel_request_code: str,
            platform_code=None,
            shop_list=None,
            account_id=None
    ) -> Response:
        """获取账号"""
        dictionary = {
            "shovel_request_code": shovel_request_code,
        }
        if platform_code is not None:
            dictionary['platform_code'] = platform_code
        if shop_list is not None:
            dictionary['shop_list'] = shop_list
        if account_id is not None:
            dictionary['account_id'] = account_id

        return self.request_open_api(
            "KaiwaOpenApiController/getShovelRequestRelatedAccounts",
            dictionary
        )

    def call_get_accounts_without_long_session(self, account_id_list: List[int], platform_code: str) -> Response:
        """筛选出没有可用的 LONG 类型的会话的 account_id"""
        return self.request_open_api(
            'KaiwaOpenApiController/getAccountsWithoutLongSession',
            {'account_id_list': account_id_list, 'platform_code': platform_code}
        )

    def call_get_count_of_special_cookie(self, name: str):
        """获取特殊cookie的数量"""
        return self.request_open_api('KaiwaOpenApiController/getCountOfSpecialCookie', {'name': name})

    def call_get_count_of_unused_valid_special_cookie(self, name: str):
        return self.request_open_api('KaiwaOpenApiController/getUnusedCountOfValidSpecialCookie',
                                     {'name': name})

    def call_request_one_time_shovel_task(
            self,
            task_title: str,
            target_machine: str,
            shovel_project: str,
            shovel_class: str,
            shovel_extra: dict = None,
            locks: Iterable[dict] = None
    ) -> Response:
        """
        发起一个单次Shovel任务
        :param task_title:
        :param target_machine:
        :param shovel_project:
        :param shovel_class:
        :param shovel_extra:
        :param locks: format: {lock_name: '', addition: ''}
        :return:
        """
        payload = {
            "task_title": task_title,
            "target_machine": target_machine,
            "shovel_project": shovel_project,
            "shovel_class": shovel_class,
        }
        if shovel_extra is not None:
            payload['shovel_extra'] = shovel_extra
        if locks is not None:
            payload['locks'] = locks
        return self.request_open_api(
            "QueueOpenApiController/requestOneTimeShovelTask",
            payload
        )
